@@ -1,12 +1,14 @@
 #!/bin/bash
 
-release=1.0
+release=1.4
 
 echo "********** Copying taglib -> taglib-$release..."
 
 cd taglib
 perl admin/cvs-clean.pl
-cd ..
+cd taglib
+perl ../admin/svn-clean.pl -f
+cd ../..
 
 rm -rf taglib-$release
 cp -a taglib taglib-$release
@@ -28,6 +30,7 @@ rm -r autom4te.cache
 echo "********** Removing CVS and .cvsignore files..."
 find . -name CVS -type d | xargs rm -r
 find . -name .cvsignore -type f | xargs rm
+find . -name .svn -type d | xargs rm -r
 
 echo "********** Creating tarball..."
 
