@@ -39,8 +39,11 @@ public:
   }
 
   File *file;
+  static List<const FileTypeResolver *> fileTypeResolvers;
 };
 
+List<const FileRef::FileTypeResolver *> FileRef::FileRefPrivate::fileTypeResolvers;
+
 ////////////////////////////////////////////////////////////////////////////////
 // public members
 ////////////////////////////////////////////////////////////////////////////////
@@ -92,6 +95,24 @@ bool FileRef::save()
   return d->file->save();
 }
 
+const FileRef::FileTypeResolver *FileRef::addFileTypeResolver(const FileRef::FileTypeResolver *resolver) // static
+{
+  FileRefPrivate::fileTypeResolvers.prepend(resolver);
+  return resolver;
+}
+
+StringList FileRef::defaultFileExtensions()
+{
+  StringList l;
+
+  l.append("ogg");
+  l.append("flac");
+  l.append("mp3");
+  l.append("mpc");
+
+  return l;
+}
+
 bool FileRef::isNull() const
 {
   return !d->file || !d->file->isValid();
@@ -124,10 +145,23 @@ bool FileRef::operator!=(const FileRef &ref) const
 File *FileRef::create(const char *fileName, bool readAudioProperties,
                       AudioProperties::ReadStyle audioPropertiesStyle) // static
 {
+
+  List<const FileTypeResolver *>::ConstIterator it = FileRefPrivate::fileTypeResolvers.begin();
+
+  for(; it != FileRefPrivate::fileTypeResolvers.end(); ++it) {
+    File *file = (*it)->createFile(fileName, readAudioProperties, audioPropertiesStyle);
+    if(file)
+      return file;
+  }
+
   // Ok, this is really dumb for now, but it works for testing.
 
   String s = fileName;
 
+  // If this list is updated, the method defaultFileExtensions() should also be
+  // updated.  However at some point that list should be created at the same time
+  // that a default file type resolver is created.
+
   if(s.size() > 4) {
     if(s.substr(s.size() - 4, 4).upper() == ".OGG")
       return new Vorbis::File(fileName, readAudioProperties, audioPropertiesStyle);
@@ -137,7 +171,7 @@ File *FileRef::create(const char *fileName, bool readAudioProperties,
       return new FLAC::File(fileName, readAudioProperties, audioPropertiesStyle);
     if(s.substr(s.size() - 4, 4).upper() == ".MPC")
       return new MPC::File(fileName, readAudioProperties, audioPropertiesStyle);
-  }
+  }  
 
   return 0;
 }
