@@ -30,8 +30,9 @@ using namespace TagLib;
 class FLAC::Properties::PropertiesPrivate
 {
 public:
-  PropertiesPrivate(File *f, ReadStyle s) :
-    file(f),
+  PropertiesPrivate(ByteVector d, long st, ReadStyle s) :
+    data(d),
+    streamLength(st),
     style(s),
     length(0),
     bitrate(0),
@@ -39,7 +40,8 @@ public:
     sampleWidth(0),
     channels(0) {}
 
-  File *file;
+  ByteVector data;
+  long streamLength;
   ReadStyle style;
   int length;
   int bitrate;
@@ -52,12 +54,18 @@ public:
 // public members
 ////////////////////////////////////////////////////////////////////////////////
 
-FLAC::Properties::Properties(File *file, ReadStyle style) : AudioProperties(style)
+FLAC::Properties::Properties(ByteVector data, long streamLength, ReadStyle style) : AudioProperties(style)
 {
-  d = new PropertiesPrivate(file, style);
+  d = new PropertiesPrivate(data, streamLength, style);
   read();
 }
 
+FLAC::Properties::Properties(File *file, ReadStyle style) : AudioProperties(style)
+{
+  d = new PropertiesPrivate(file->streamInfoData(), file->streamLength(), style);
+  read();
+}	
+
 FLAC::Properties::~Properties()
 {
   delete d;
@@ -94,9 +102,10 @@ int FLAC::Properties::channels() const
 
 void FLAC::Properties::read()
 {
-  // Get the identification header.
-
-  ByteVector data = d->file->streamInfoData();
+  if(d->data.size() < 18) {
+    debug("FLAC::Properties::read() - FLAC properties must contain at least 18 bytes.");
+    return;
+  }
 
   int pos = 0;
 
@@ -112,27 +121,26 @@ void FLAC::Properties::read()
   // Maximum frame size (in bytes)
   pos += 3;
 
-  uint flags = data.mid(pos, 4).toUInt(true);
+  uint flags = d->data.mid(pos, 4).toUInt(true);
   d->sampleRate = flags >> 12;
   d->channels = ((flags >> 9) & 7) + 1;
   d->sampleWidth = ((flags >> 4) & 31) + 1;
 
-  // The last 4 bit are the most significant 4 bits for the 36bit
-  // streamlength in samples. (Audio files measured in days)
+  // The last 4 bits are the most significant 4 bits for the 36 bit
+  // stream length in samples. (Audio files measured in days)
 
-  uint highlength = (((flags & 0xf) << 28) / d->sampleRate) << 4;
+  uint highLength =d->sampleRate > 0 ? (((flags & 0xf) << 28) / d->sampleRate) << 4 : 0;
   pos += 4;
 
-  d->length = (data.mid(pos, 4).toUInt(true)) / d->sampleRate + highlength;
+  d->length = d->sampleRate > 0 ?
+      (d->data.mid(pos, 4).toUInt(true)) / d->sampleRate + highLength : 0;
   pos += 4;
 
   // Uncompressed bitrate:
   
-  // d->bitrate = ((d->sampleRate * d->channels) / 1000) * d->sampleWidth;
+  //d->bitrate = ((d->sampleRate * d->channels) / 1000) * d->sampleWidth;
   
   // Real bitrate:
   
-  d->bitrate = ((d->file->streamLength()*8L) / d->length)/1000;
-  
-  
+  d->bitrate = d->length > 0 ? ((d->streamLength * 8L) / d->length) / 1000 : 0;
 }
